# -*- coding: utf-8 -*-
##################################################
#
# dvm
# Package | Data Visualization Models
# 
# Interactive & Visual Models for Data 
# Representation.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import article
from . import cell
from . import file
from . import graph
from . import table

from .article import *
from .cell import *
from .file import *
from .graph import *
from .table import *


# -*- coding: utf-8 -*-
##################################################
#
# network
# Package | Network
#
# Daniel Bakas Amuchastegui
# March 16, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import genealogical_tree
from . import network

from .genealogical_tree import *
from .network import *


# -*- coding: utf-8 -*-
##################################################
#
# article
# Module | Article
# 
# Written compositions describing the content of 
# a Resouce, through the use of Cells.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################


# -*- coding: utf-8 -*-
##################################################
#
# semantyk 
# Package | Semantyk
#
# Author: Daniel Bakas Amuchastegui
# August 31, 2017
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

__author__ = 'Daniel Bakas Amuchastegui'
__email__ = 'danielbakas@gmail.com'
__version__ = '0.0.0.48'

from . import archive
from . import av_reality
from . import das
from . import dots
from . import dvm
from . import games
from . import learn
from . import sam
from . import store
from . import tools
from . import uuid_generator

from .archive import *
from .av_reality import *
from .dots import *
from .dvm import *
from .games import *
from .learn import *
from .sam import *
from .store import *
from .tools import *
from .uuid_generator import *


# -*- coding: utf-8 -*-
##################################################
#
# file
# Module | File
# 
# Structured and compact formats diplaying the 
# content of a Resource, through the use of Cells.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################


# -*- coding: utf-8 -*-
##################################################
#
# archive 
# Package | Archive
# 
# File System Package.
#
# Author: Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import user

from .user import *


# -*- coding: utf-8 -*-
##################################################
#
# cell
# Module | Cell
# 
# Main component of a Data Visualization Model 
# like Articles or File Cards.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################